"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_maintenances_createmaintenancerequest import (
    V4StatusPagesMaintenancesCreateMaintenanceRequest,
    V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict,
)
from .v4_statuspages_maintenances_createmaintenanceresponse import (
    V4StatusPagesMaintenancesCreateMaintenanceResponse,
    V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class MaintenancesCreateMaintenanceRequestTypedDict(TypedDict):
    statuspage_id: str
    v4_status_pages_maintenances_create_maintenance_request: (
        V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict
    )


class MaintenancesCreateMaintenanceRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_status_pages_maintenances_create_maintenance_request: Annotated[
        V4StatusPagesMaintenancesCreateMaintenanceRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class MaintenancesCreateMaintenanceResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict


class MaintenancesCreateMaintenanceResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesCreateMaintenanceResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_icallinkresponse import V4ICalLinkResponse, V4ICalLinkResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing_extensions import Annotated, TypedDict


class ExportRefreshScheduleIcalLinkRequestBodyTypedDict(TypedDict):
    pass


class ExportRefreshScheduleIcalLinkRequestBody(BaseModel):
    pass


class ExportRefreshScheduleIcalLinkRequestTypedDict(TypedDict):
    schedule_id: str
    my_on_call: bool
    request_body: ExportRefreshScheduleIcalLinkRequestBodyTypedDict


class ExportRefreshScheduleIcalLinkRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    my_on_call: Annotated[
        bool,
        pydantic.Field(alias="myOnCall"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ]

    request_body: Annotated[
        ExportRefreshScheduleIcalLinkRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ExportRefreshScheduleIcalLinkResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4ICalLinkResponseTypedDict


class ExportRefreshScheduleIcalLinkResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4ICalLinkResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3EscalationPoliciesIncidentReminderRuleTypedDict(TypedDict):
    r"""Represents a rule for sending incident reminders."""

    via: List[str]
    r"""The notification methods to use for the reminder."""
    time_interval: int
    r"""The interval in minutes at which to send the reminder."""
    till: int
    r"""The duration in minutes for which to send reminders."""


class V3EscalationPoliciesIncidentReminderRule(BaseModel):
    r"""Represents a rule for sending incident reminders."""

    via: List[str]
    r"""The notification methods to use for the reminder."""

    time_interval: int
    r"""The interval in minutes at which to send the reminder."""

    till: int
    r"""The duration in minutes for which to send reminders."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_jiracreateticketupdate import (
    V3WorkflowsJiraCreateTicketUpdate,
    V3WorkflowsJiraCreateTicketUpdateTypedDict,
)
from .v3_workflows_msteamscreatemeetinglinkupdate import (
    V3WorkflowsMsTeamsCreateMeetingLinkUpdate,
    V3WorkflowsMsTeamsCreateMeetingLinkUpdateTypedDict,
)
from .v3_workflows_msteamsmessagechannelupdate import (
    V3WorkflowsMsTeamsMessageChannelUpdate,
    V3WorkflowsMsTeamsMessageChannelUpdateTypedDict,
)
from .v3_workflows_msteamsmessageuserupdate import (
    V3WorkflowsMsTeamsMessageUserUpdate,
    V3WorkflowsMsTeamsMessageUserUpdateTypedDict,
)
from .v3_workflows_slackarchivechannelupdate import (
    V3WorkflowsSlackArchiveChannelUpdate,
    V3WorkflowsSlackArchiveChannelUpdateTypedDict,
)
from .v3_workflows_slackcreateincidentchannelupdate import (
    V3WorkflowsSlackCreateIncidentChannelUpdate,
    V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict,
)
from .v3_workflows_slackmessagechannelupdate import (
    V3WorkflowsSlackMessageChannelUpdate,
    V3WorkflowsSlackMessageChannelUpdateTypedDict,
)
from .v3_workflows_slackmessageuserupdate import (
    V3WorkflowsSlackMessageUserUpdate,
    V3WorkflowsSlackMessageUserUpdateTypedDict,
)
from .v3_workflows_sqaddcommunicationchannelupdate import (
    V3WorkflowsSqAddCommunicationChannelUpdate,
    V3WorkflowsSqAddCommunicationChannelUpdateTypedDict,
)
from .v3_workflows_sqaddincidentnoteupdate import (
    V3WorkflowsSqAddIncidentNoteUpdate,
    V3WorkflowsSqAddIncidentNoteUpdateTypedDict,
)
from .v3_workflows_sqcreatestatuspageissueupdate import (
    V3WorkflowsSqCreateStatusPageIssueUpdate,
    V3WorkflowsSqCreateStatusPageIssueUpdateTypedDict,
)
from .v3_workflows_sqmakehttpcallupdate import (
    V3WorkflowsSqMakeHTTPCallUpdate,
    V3WorkflowsSqMakeHTTPCallUpdateTypedDict,
)
from .v3_workflows_sqmarkincidentsloaffectingupdate import (
    V3WorkflowsSqMarkIncidentSLOAffectingUpdate,
    V3WorkflowsSqMarkIncidentSLOAffectingUpdateTypedDict,
)
from .v3_workflows_sqsendemailupdate import (
    V3WorkflowsSqSendEmailUpdate,
    V3WorkflowsSqSendEmailUpdateTypedDict,
)
from .v3_workflows_sqtriggermanualwebhookupdate import (
    V3WorkflowsSqTriggerManualWebhookUpdate,
    V3WorkflowsSqTriggerManualWebhookUpdateTypedDict,
)
from .v3_workflows_updateincidentpriorityupdate import (
    V3WorkflowsUpdateIncidentPriorityUpdate,
    V3WorkflowsUpdateIncidentPriorityUpdateTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import Any, List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


V3WorkflowsActionRequestUpdateName = Literal["sq_attach_runbooks",]


class V3WorkflowsActionRequestUpdateDataTypedDict(TypedDict):
    runbooks: NotRequired[List[str]]


class V3WorkflowsActionRequestUpdateData(BaseModel):
    runbooks: Optional[List[str]] = None


class V3WorkflowsActionRequestUpdateSqAttachRunbooksTypedDict(TypedDict):
    name: V3WorkflowsActionRequestUpdateName
    data: NotRequired[V3WorkflowsActionRequestUpdateDataTypedDict]


class V3WorkflowsActionRequestUpdateSqAttachRunbooks(BaseModel):
    name: V3WorkflowsActionRequestUpdateName

    data: Optional[V3WorkflowsActionRequestUpdateData] = None


V3WorkflowsActionRequestUpdateTypedDict = TypeAliasType(
    "V3WorkflowsActionRequestUpdateTypedDict",
    Union[
        V3WorkflowsSlackArchiveChannelUpdateTypedDict,
        V3WorkflowsMsTeamsCreateMeetingLinkUpdateTypedDict,
        V3WorkflowsSlackMessageChannelUpdateTypedDict,
        V3WorkflowsSlackMessageUserUpdateTypedDict,
        V3WorkflowsSqCreateStatusPageIssueUpdateTypedDict,
        V3WorkflowsSqAddIncidentNoteUpdateTypedDict,
        V3WorkflowsSqTriggerManualWebhookUpdateTypedDict,
        V3WorkflowsSqAddCommunicationChannelUpdateTypedDict,
        V3WorkflowsActionRequestUpdateSqAttachRunbooksTypedDict,
        V3WorkflowsUpdateIncidentPriorityUpdateTypedDict,
        V3WorkflowsSqMakeHTTPCallUpdateTypedDict,
        V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict,
        V3WorkflowsJiraCreateTicketUpdateTypedDict,
        V3WorkflowsMsTeamsMessageChannelUpdateTypedDict,
        V3WorkflowsMsTeamsMessageUserUpdateTypedDict,
        V3WorkflowsSqSendEmailUpdateTypedDict,
        V3WorkflowsSqMarkIncidentSLOAffectingUpdateTypedDict,
        Any,
    ],
)


V3WorkflowsActionRequestUpdate = TypeAliasType(
    "V3WorkflowsActionRequestUpdate",
    Union[
        V3WorkflowsSlackArchiveChannelUpdate,
        V3WorkflowsMsTeamsCreateMeetingLinkUpdate,
        V3WorkflowsSlackMessageChannelUpdate,
        V3WorkflowsSlackMessageUserUpdate,
        V3WorkflowsSqCreateStatusPageIssueUpdate,
        V3WorkflowsSqAddIncidentNoteUpdate,
        V3WorkflowsSqTriggerManualWebhookUpdate,
        V3WorkflowsSqAddCommunicationChannelUpdate,
        V3WorkflowsActionRequestUpdateSqAttachRunbooks,
        V3WorkflowsUpdateIncidentPriorityUpdate,
        V3WorkflowsSqMakeHTTPCallUpdate,
        V3WorkflowsSlackCreateIncidentChannelUpdate,
        V3WorkflowsJiraCreateTicketUpdate,
        V3WorkflowsMsTeamsMessageChannelUpdate,
        V3WorkflowsMsTeamsMessageUserUpdate,
        V3WorkflowsSqSendEmailUpdate,
        V3WorkflowsSqMarkIncidentSLOAffectingUpdate,
        Any,
    ],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GlobalEventRulesDeleteGerRulesetRequestTypedDict(TypedDict):
    ger_id: int
    alert_source_version: str
    alert_source_shortname: str


class GlobalEventRulesDeleteGerRulesetRequest(BaseModel):
    ger_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_version: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_shortname: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GlobalEventRulesDeleteGerRulesetResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class GlobalEventRulesDeleteGerRulesetResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3UsersAddUserRequestRole = Literal[
    "account_owner",
    "user",
    "stakeholder",
]


class V3UsersAddUserRequestTypedDict(TypedDict):
    email: str
    role: V3UsersAddUserRequestRole
    first_name: str
    last_name: str


class V3UsersAddUserRequest(BaseModel):
    email: str

    role: V3UsersAddUserRequestRole

    first_name: str

    last_name: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_exportformat import V3IncidentsExportFormat
from .v3_incidents_incidentexportrequest_is_starred import (
    V3IncidentsIncidentExportRequestIsStarred,
)
from .v3_incidents_incidentexportrequest_notes import (
    V3IncidentsIncidentExportRequestNotes,
)
from .v3_incidents_incidentexportrequest_retrospectives import (
    V3IncidentsIncidentExportRequestRetrospectives,
)
from .v3_incidents_incidentexportrequest_slo_affecting import (
    V3IncidentsIncidentExportRequestSloAffecting,
)
from .v3_incidents_incidentexportrequest_sort_by import (
    V3IncidentsIncidentExportRequestSortBy,
)
from .v3_incidents_incidentpriority import V3IncidentsIncidentPriority
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IncidentsIncidentExportRequestTypedDict(TypedDict):
    start_time: datetime
    end_time: datetime
    type: V3IncidentsExportFormat
    r"""Defines the format of the export."""
    owner_id: str
    status: NotRequired[List[str]]
    services: NotRequired[List[str]]
    sources: NotRequired[List[str]]
    assigned_to: NotRequired[List[str]]
    assigned_to_user_i_ds_and_their_squads: NotRequired[List[str]]
    service_owner: NotRequired[str]
    priority: NotRequired[List[V3IncidentsIncidentPriority]]
    tags: NotRequired[List[str]]
    slo_affecting: NotRequired[V3IncidentsIncidentExportRequestSloAffecting]
    slos: NotRequired[List[int]]
    is_starred: NotRequired[V3IncidentsIncidentExportRequestIsStarred]
    text_filter: NotRequired[str]
    notes: NotRequired[V3IncidentsIncidentExportRequestNotes]
    retrospectives: NotRequired[V3IncidentsIncidentExportRequestRetrospectives]
    sort_by: NotRequired[V3IncidentsIncidentExportRequestSortBy]


class IncidentsIncidentExportRequest(BaseModel):
    start_time: Annotated[
        datetime, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]

    end_time: Annotated[
        datetime, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]

    type: Annotated[
        V3IncidentsExportFormat,
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ]
    r"""Defines the format of the export."""

    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]

    status: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    services: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    sources: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    assigned_to: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    assigned_to_user_i_ds_and_their_squads: Annotated[
        Optional[List[str]],
        pydantic.Field(alias="assignedToUserIDsAndTheirSquads"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    service_owner: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    priority: Annotated[
        Optional[List[V3IncidentsIncidentPriority]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    tags: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    slo_affecting: Annotated[
        Optional[V3IncidentsIncidentExportRequestSloAffecting],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    slos: Annotated[
        Optional[List[int]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    is_starred: Annotated[
        Optional[V3IncidentsIncidentExportRequestIsStarred],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    text_filter: Annotated[
        Optional[str],
        pydantic.Field(alias="textFilter"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    notes: Annotated[
        Optional[V3IncidentsIncidentExportRequestNotes],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    retrospectives: Annotated[
        Optional[V3IncidentsIncidentExportRequestRetrospectives],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    sort_by: Annotated[
        Optional[V3IncidentsIncidentExportRequestSortBy],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from squadcast_sdk import errors, models, utils
from squadcast_sdk._hooks import HookContext
from squadcast_sdk.types import OptionalNullable, UNSET
from squadcast_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional


class MsTeams1(BaseSDK):
    def get_config(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3ExtensionsMSTeamsMSTeamsConfigResponse:
        r"""Get MSTeams Config

        Returns MSTeams config of the organization.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request(
            method="GET",
            path="/v3/extensions/msteams/config",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="MSTeams_getMsteamsConfig",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.MSTeamsGetMsteamsConfigResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def get_config_async(
        self,
        *,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3ExtensionsMSTeamsMSTeamsConfigResponse:
        r"""Get MSTeams Config

        Returns MSTeams config of the organization.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)
        req = self._build_request_async(
            method="GET",
            path="/v3/extensions/msteams/config",
            base_url=base_url,
            url_variables=url_variables,
            request=None,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="MSTeams_getMsteamsConfig",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.MSTeamsGetMsteamsConfigResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3SLOTimeIntervalType = Literal[
    "fixed",
    "rolling",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesComponentsCreateComponentRequestTypedDict(TypedDict):
    name: str
    description: NotRequired[str]
    allow_subscription: NotRequired[bool]
    group_id: NotRequired[str]
    service_id: NotRequired[str]


class V4StatusPagesComponentsCreateComponentRequest(BaseModel):
    name: str

    description: Optional[str] = None

    allow_subscription: Annotated[
        Optional[bool], pydantic.Field(alias="allowSubscription")
    ] = None

    group_id: Annotated[Optional[str], pydantic.Field(alias="groupID")] = None

    service_id: Annotated[Optional[str], pydantic.Field(alias="serviceID")] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_maintenancemode_createorupdatemaintenancemoderequest import (
    V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest,
    V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class MaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict(TypedDict):
    service_id: str
    v3_services_maintenance_mode_create_or_update_maintenance_mode_request: (
        V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict
    )


class MaintenanceModeCreateOrUpdateMaintenanceModeRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_maintenance_mode_create_or_update_maintenance_mode_request: Annotated[
        V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class MaintenanceModeCreateOrUpdateMaintenanceModeResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class MaintenanceModeCreateOrUpdateMaintenanceModeResponse(BaseModel):
    r"""The request has succeeded."""

    data: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_enabledisableworkflowrequest import (
    V3WorkflowsEnableDisableWorkflowRequest,
    V3WorkflowsEnableDisableWorkflowRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class WorkflowsEnabledisableWorkflowRequestTypedDict(TypedDict):
    workflow_id: str
    v3_workflows_enable_disable_workflow_request: (
        V3WorkflowsEnableDisableWorkflowRequestTypedDict
    )


class WorkflowsEnabledisableWorkflowRequest(BaseModel):
    workflow_id: Annotated[
        str,
        pydantic.Field(alias="workflowID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_workflows_enable_disable_workflow_request: Annotated[
        V3WorkflowsEnableDisableWorkflowRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class WorkflowsEnabledisableWorkflowResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class WorkflowsEnabledisableWorkflowResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesSuppressionRulesBasicExpressionTypedDict(TypedDict):
    lhs: str
    op: str
    rhs: str


class V3ServicesSuppressionRulesBasicExpression(BaseModel):
    lhs: str

    op: str

    rhs: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_tag import V4Tag, V4TagTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


V4CreateScheduleRequestOwnerType = Literal[
    "user",
    "squad",
]


class V4CreateScheduleRequestTypedDict(TypedDict):
    name: str
    description: str
    team_id: str
    owner_id: str
    owner_type: V4CreateScheduleRequestOwnerType
    time_zone: str
    tags: List[V4TagTypedDict]


class V4CreateScheduleRequest(BaseModel):
    name: str

    description: str

    team_id: Annotated[str, pydantic.Field(alias="teamID")]

    owner_id: Annotated[str, pydantic.Field(alias="ownerID")]

    owner_type: Annotated[
        V4CreateScheduleRequestOwnerType, pydantic.Field(alias="ownerType")
    ]

    time_zone: Annotated[str, pydantic.Field(alias="timeZone")]

    tags: List[V4Tag]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .common_v4_pageinfo import CommonV4PageInfo, CommonV4PageInfoTypedDict
from .v4_scheduleresponse import V4ScheduleResponse, V4ScheduleResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import Callable, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SchedulesListSchedulesRequestTypedDict(TypedDict):
    team_id: str
    schedule_i_ds: NotRequired[List[int]]
    participants: NotRequired[List[str]]
    schedule_name: NotRequired[str]
    my_on_call: NotRequired[bool]
    you_and_your_squads: NotRequired[bool]
    search: NotRequired[str]
    hide_paused: NotRequired[bool]
    owner_id: NotRequired[str]
    escalation_policies: NotRequired[List[str]]
    without_escalation_policy: NotRequired[bool]
    page_size: NotRequired[int]
    cursor: NotRequired[str]


class SchedulesListSchedulesRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ]

    schedule_i_ds: Annotated[
        Optional[List[int]],
        pydantic.Field(alias="scheduleIDs"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    participants: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    schedule_name: Annotated[
        Optional[str],
        pydantic.Field(alias="scheduleName"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    my_on_call: Annotated[
        Optional[bool],
        pydantic.Field(alias="myOnCall"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    you_and_your_squads: Annotated[
        Optional[bool],
        pydantic.Field(alias="youAndYourSquads"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    search: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    hide_paused: Annotated[
        Optional[bool],
        pydantic.Field(alias="hidePaused"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    owner_id: Annotated[
        Optional[str],
        pydantic.Field(alias="ownerID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    escalation_policies: Annotated[
        Optional[List[str]],
        pydantic.Field(alias="escalationPolicies"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    without_escalation_policy: Annotated[
        Optional[bool],
        pydantic.Field(alias="withoutEscalationPolicy"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    page_size: Annotated[
        Optional[int],
        pydantic.Field(alias="pageSize"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None


class SchedulesListSchedulesResponseBodyTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V4ScheduleResponseTypedDict]
    page_info: CommonV4PageInfoTypedDict


class SchedulesListSchedulesResponseBody(BaseModel):
    r"""The request has succeeded."""

    data: List[V4ScheduleResponse]

    page_info: Annotated[CommonV4PageInfo, pydantic.Field(alias="pageInfo")]


class SchedulesListSchedulesResponseTypedDict(TypedDict):
    result: SchedulesListSchedulesResponseBodyTypedDict


class SchedulesListSchedulesResponse(BaseModel):
    next: Callable[[], Optional[SchedulesListSchedulesResponse]]

    result: SchedulesListSchedulesResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsTagsUpdateTagRequestTagsTypedDict(TypedDict):
    pass


class V3IncidentsTagsUpdateTagRequestTags(BaseModel):
    pass


class V3IncidentsTagsUpdateTagRequestTypedDict(TypedDict):
    tags: V3IncidentsTagsUpdateTagRequestTagsTypedDict


class V3IncidentsTagsUpdateTagRequest(BaseModel):
    tags: V3IncidentsTagsUpdateTagRequestTags



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Any, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EntityTypedDict(TypedDict):
    pass


class Entity(BaseModel):
    pass


class V3WorkflowsCreateWorkflowFilterTypedDict(TypedDict):
    type: NotRequired[str]
    key: NotRequired[str]
    value: NotRequired[Any]
    fields: NotRequired[V3WorkflowsCreateWorkflowFilterTypedDict]
    children: NotRequired[List[V3WorkflowsCreateWorkflowFilterTypedDict]]
    label: NotRequired[str]
    entity: NotRequired[EntityTypedDict]
    filter_type: NotRequired[str]


class V3WorkflowsCreateWorkflowFilter(BaseModel):
    type: Optional[str] = None

    key: Optional[str] = None

    value: Optional[Any] = None

    fields: Optional[V3WorkflowsCreateWorkflowFilter] = None

    children: Optional[List[V3WorkflowsCreateWorkflowFilter]] = None

    label: Optional[str] = None

    entity: Optional[Entity] = None

    filter_type: Annotated[Optional[str], pydantic.Field(alias="filterType")] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3UsersGlobalRBACAbilityName = Literal[
    "manage-api-tokens",
    "manage-billing",
    "manage-extensions",
    "manage-teams",
    "manage-users",
    "manage-webhooks",
    "manage-organization-analytics",
    "manage-postmortem-templates",
    "manage-audit-logs",
    "manage-feature-settings",
]
r"""Represents the name of a global RBAC ability."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_scheduleresponse import V4ScheduleResponse, V4ScheduleResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SchedulesCloneScheduleRequestBodyTypedDict(TypedDict):
    pass


class SchedulesCloneScheduleRequestBody(BaseModel):
    pass


class SchedulesCloneScheduleRequestTypedDict(TypedDict):
    schedule_id: str
    request_body: SchedulesCloneScheduleRequestBodyTypedDict


class SchedulesCloneScheduleRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    request_body: Annotated[
        SchedulesCloneScheduleRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SchedulesCloneScheduleResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4ScheduleResponseTypedDict


class SchedulesCloneScheduleResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4ScheduleResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsTagsAssignToTypedDict(TypedDict):
    r"""Represents the assignment target for delayed notifications."""

    id: str
    type: NotRequired[str]


class V3IncidentsTagsAssignTo(BaseModel):
    r"""Represents the assignment target for delayed notifications."""

    id: str

    type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class UsersGetUserByIDRequestTypedDict(TypedDict):
    user_id: str
    r"""(Required) user id"""


class UsersGetUserByIDRequest(BaseModel):
    user_id: Annotated[
        str,
        pydantic.Field(alias="userID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""(Required) user id"""


class UsersGetUserByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3UsersUserResponseTypedDict


class UsersGetUserByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3UsersUserResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3GlobalEventRulesReorderRuleRequestTypedDict(TypedDict):
    shift_to: NotRequired[str]
    shift_index_by: NotRequired[int]


class V3GlobalEventRulesReorderRuleRequest(BaseModel):
    shift_to: Optional[str] = None

    shift_index_by: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_ruleaction import (
    V3GlobalEventRulesRuleAction,
    V3GlobalEventRulesRuleActionTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3GlobalEventRulesCreateOrUpdateRuleRequestTypedDict(TypedDict):
    description: str
    expression: str
    action: V3GlobalEventRulesRuleActionTypedDict


class V3GlobalEventRulesCreateOrUpdateRuleRequest(BaseModel):
    description: str

    expression: str

    action: V3GlobalEventRulesRuleAction



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsTagsAppendTagRequestTagsTypedDict(TypedDict):
    pass


class V3IncidentsTagsAppendTagRequestTags(BaseModel):
    pass


class V3IncidentsTagsAppendTagRequestTypedDict(TypedDict):
    tags: NotRequired[V3IncidentsTagsAppendTagRequestTagsTypedDict]


class V3IncidentsTagsAppendTagRequest(BaseModel):
    tags: Optional[V3IncidentsTagsAppendTagRequestTags] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict(TypedDict):
    service_id: str
    maintenance_from: datetime
    maintenance_till: datetime
    repetition_daily: bool
    repetition_weekly: bool
    repetition_two_weekly: bool
    repetition_three_weekly: bool
    repetition_monthly: bool
    deleted: bool
    repeat_till: datetime


class V3ServicesMaintenanceModeMaintenanceModeResponse(BaseModel):
    service_id: str

    maintenance_from: datetime

    maintenance_till: datetime

    repetition_daily: bool

    repetition_weekly: bool

    repetition_two_weekly: bool

    repetition_three_weekly: bool

    repetition_monthly: bool

    deleted: bool

    repeat_till: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_incidentactions_circlecirebuildresponse import (
    V3IncidentsIncidentActionsCircleCIRebuildResponse,
    V3IncidentsIncidentActionsCircleCIRebuildResponseTypedDict,
)
from .v3_incidents_incidentactions_rebuildcircleciprojectrequest import (
    V3IncidentsIncidentActionsRebuildCircleCIProjectRequest,
    V3IncidentsIncidentActionsRebuildCircleCIProjectRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IncidentActionsRebuildAProjectInCircleciRequestTypedDict(TypedDict):
    incident_id: str
    build_number: str
    v3_incidents_incident_actions_rebuild_circle_ci_project_request: (
        V3IncidentsIncidentActionsRebuildCircleCIProjectRequestTypedDict
    )


class IncidentActionsRebuildAProjectInCircleciRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    build_number: Annotated[
        str,
        pydantic.Field(alias="buildNumber"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_incident_actions_rebuild_circle_ci_project_request: Annotated[
        V3IncidentsIncidentActionsRebuildCircleCIProjectRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class IncidentActionsRebuildAProjectInCircleciMetaTypedDict(TypedDict):
    status_code: int


class IncidentActionsRebuildAProjectInCircleciMeta(BaseModel):
    status_code: int


class IncidentActionsRebuildAProjectInCircleciResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsIncidentActionsCircleCIRebuildResponseTypedDict
    r"""Represents the response structure for rebuilding a project in CircleCI."""
    meta: NotRequired[IncidentActionsRebuildAProjectInCircleciMetaTypedDict]


class IncidentActionsRebuildAProjectInCircleciResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsIncidentActionsCircleCIRebuildResponse
    r"""Represents the response structure for rebuilding a project in CircleCI."""

    meta: Optional[IncidentActionsRebuildAProjectInCircleciMeta] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaloncallreminderrules_rule import (
    V3GlobalOncallReminderRulesRule,
    V3GlobalOncallReminderRulesRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict(TypedDict):
    id: int
    is_enabled: bool
    owner_id: str
    rules: List[V3GlobalOncallReminderRulesRuleTypedDict]


class V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse(BaseModel):
    id: int

    is_enabled: bool

    owner_id: str

    rules: List[V3GlobalOncallReminderRulesRule]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_overrideresponse import V4OverrideResponse, V4OverrideResponseTypedDict
from .v4_updatescheduleoverriderequest import (
    V4UpdateScheduleOverrideRequest,
    V4UpdateScheduleOverrideRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverridesUpdateScheduleOverrideRequestTypedDict(TypedDict):
    schedule_id: str
    override_id: str
    v4_update_schedule_override_request: V4UpdateScheduleOverrideRequestTypedDict


class OverridesUpdateScheduleOverrideRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    override_id: Annotated[
        str,
        pydantic.Field(alias="overrideID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_update_schedule_override_request: Annotated[
        V4UpdateScheduleOverrideRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverridesUpdateScheduleOverrideResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4OverrideResponseTypedDict


class OverridesUpdateScheduleOverrideResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4OverrideResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_tags_analyticsmetrics import (
    V3IncidentsTagsAnalyticsMetrics,
    V3IncidentsTagsAnalyticsMetricsTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsTagsAnalyticsTypedDict(TypedDict):
    r"""Incident analytics data."""

    tta: V3IncidentsTagsAnalyticsMetricsTypedDict
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""
    ttr: V3IncidentsTagsAnalyticsMetricsTypedDict
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""


class V3IncidentsTagsAnalytics(BaseModel):
    r"""Incident analytics data."""

    tta: V3IncidentsTagsAnalyticsMetrics
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""

    ttr: V3IncidentsTagsAnalyticsMetrics
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqMakeHTTPCallName = Literal["sq_make_http_call",]


V3WorkflowsSqMakeHTTPCallMethod = Literal[
    "GET",
    "POST",
    "PUT",
    "PATCH",
    "DELETE",
]


class V3WorkflowsSqMakeHTTPCallHeaderTypedDict(TypedDict):
    key: str
    value: str


class V3WorkflowsSqMakeHTTPCallHeader(BaseModel):
    key: str

    value: str


class V3WorkflowsSqMakeHTTPCallDataTypedDict(TypedDict):
    method: V3WorkflowsSqMakeHTTPCallMethod
    url: str
    headers: NotRequired[List[V3WorkflowsSqMakeHTTPCallHeaderTypedDict]]
    body: NotRequired[str]


class V3WorkflowsSqMakeHTTPCallData(BaseModel):
    method: V3WorkflowsSqMakeHTTPCallMethod

    url: str

    headers: Optional[List[V3WorkflowsSqMakeHTTPCallHeader]] = None

    body: Optional[str] = None


class V3WorkflowsSqMakeHTTPCallTypedDict(TypedDict):
    name: V3WorkflowsSqMakeHTTPCallName
    data: V3WorkflowsSqMakeHTTPCallDataTypedDict


class V3WorkflowsSqMakeHTTPCall(BaseModel):
    name: V3WorkflowsSqMakeHTTPCallName

    data: V3WorkflowsSqMakeHTTPCallData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_updateissuerequest import (
    V4StatusPagesIssuesUpdateIssueRequest,
    V4StatusPagesIssuesUpdateIssueRequestTypedDict,
)
from .v4_statuspages_issues_updateissueresponse import (
    V4StatusPagesIssuesUpdateIssueResponse,
    V4StatusPagesIssuesUpdateIssueResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class IssuesUpdateIssueRequestTypedDict(TypedDict):
    statuspage_id: str
    issue_id: str
    v4_status_pages_issues_update_issue_request: (
        V4StatusPagesIssuesUpdateIssueRequestTypedDict
    )


class IssuesUpdateIssueRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    issue_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    v4_status_pages_issues_update_issue_request: Annotated[
        V4StatusPagesIssuesUpdateIssueRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class IssuesUpdateIssueResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesUpdateIssueResponseTypedDict


class IssuesUpdateIssueResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesUpdateIssueResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_ruleaction import (
    V3GlobalEventRulesRuleAction,
    V3GlobalEventRulesRuleActionTypedDict,
)
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3GlobalEventRulesRulesetRuleResponseTypedDict(TypedDict):
    id: NotRequired[int]
    global_event_rule_id: NotRequired[int]
    description: NotRequired[str]
    expression: NotRequired[str]
    action: NotRequired[V3GlobalEventRulesRuleActionTypedDict]
    created_at: NotRequired[datetime]
    created_by: NotRequired[str]
    updated_at: NotRequired[datetime]
    updated_by: NotRequired[str]


class V3GlobalEventRulesRulesetRuleResponse(BaseModel):
    id: Optional[int] = None

    global_event_rule_id: Optional[int] = None

    description: Optional[str] = None

    expression: Optional[str] = None

    action: Optional[V3GlobalEventRulesRuleAction] = None

    created_at: Optional[datetime] = None

    created_by: Optional[str] = None

    updated_at: Optional[datetime] = None

    updated_by: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3ExtensionsWebhooksWebhookFilterConditionTypedDict(TypedDict):
    op: NotRequired[str]
    lhs: NotRequired[str]
    rhs: NotRequired[str]


class V3ExtensionsWebhooksWebhookFilterCondition(BaseModel):
    op: Optional[str] = None

    lhs: Optional[str] = None

    rhs: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqSendEmailUpdateName = Literal["sq_send_email",]


class V3WorkflowsSqSendEmailUpdateDataTypedDict(TypedDict):
    to: NotRequired[List[str]]
    subject: NotRequired[str]
    body: NotRequired[str]


class V3WorkflowsSqSendEmailUpdateData(BaseModel):
    to: Optional[List[str]] = None

    subject: Optional[str] = None

    body: Optional[str] = None


class V3WorkflowsSqSendEmailUpdateTypedDict(TypedDict):
    name: V3WorkflowsSqSendEmailUpdateName
    data: NotRequired[V3WorkflowsSqSendEmailUpdateDataTypedDict]


class V3WorkflowsSqSendEmailUpdate(BaseModel):
    name: V3WorkflowsSqSendEmailUpdateName

    data: Optional[V3WorkflowsSqSendEmailUpdateData] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3UsersContactTypedDict(TypedDict):
    dial_code: str
    phone_number: str


class V3UsersContact(BaseModel):
    dial_code: str

    phone_number: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3WebformsWFInputFieldTypedDict(TypedDict):
    r"""Input field definition for a webform"""

    label: str
    r"""Field label"""
    options: List[str]
    r"""Selectable options for this field"""


class V3WebformsWFInputField(BaseModel):
    r"""Input field definition for a webform"""

    label: str
    r"""Field label"""

    options: List[str]
    r"""Selectable options for this field"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_totalsubscriberscount import (
    V4StatusPagesTotalSubscribersCount,
    V4StatusPagesTotalSubscribersCountTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesListSubscribersResponseMetaTypedDict(TypedDict):
    maximum_subscribers_limit: int
    last_week_subscribers_count: int
    total_subscribers_count: NotRequired[V4StatusPagesTotalSubscribersCountTypedDict]


class V4StatusPagesListSubscribersResponseMeta(BaseModel):
    maximum_subscribers_limit: Annotated[
        int, pydantic.Field(alias="maximumSubscribersLimit")
    ]

    last_week_subscribers_count: Annotated[
        int, pydantic.Field(alias="lastWeekSubscribersCount")
    ]

    total_subscribers_count: Annotated[
        Optional[V4StatusPagesTotalSubscribersCount],
        pydantic.Field(alias="totalSubscribersCount"),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_createissuerequest import (
    V4StatusPagesIssuesCreateIssueRequest,
    V4StatusPagesIssuesCreateIssueRequestTypedDict,
)
from .v4_statuspages_issues_createissueresponse import (
    V4StatusPagesIssuesCreateIssueResponse,
    V4StatusPagesIssuesCreateIssueResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class IssuesCreateIssueRequestTypedDict(TypedDict):
    statuspage_id: str
    v4_status_pages_issues_create_issue_request: (
        V4StatusPagesIssuesCreateIssueRequestTypedDict
    )


class IssuesCreateIssueRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_status_pages_issues_create_issue_request: Annotated[
        V4StatusPagesIssuesCreateIssueRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class IssuesCreateIssueResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesCreateIssueResponseTypedDict


class IssuesCreateIssueResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesCreateIssueResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_statuspage import (
    V4StatusPagesStatusPage,
    V4StatusPagesStatusPageTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesListStatusPagesResponseMetaTypedDict(TypedDict):
    total_count: int
    org_total_count: int


class V4StatusPagesListStatusPagesResponseMeta(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]

    org_total_count: Annotated[int, pydantic.Field(alias="orgTotalCount")]


class V4StatusPagesListStatusPagesResponseTypedDict(TypedDict):
    data: List[V4StatusPagesStatusPageTypedDict]
    meta: V4StatusPagesListStatusPagesResponseMetaTypedDict


class V4StatusPagesListStatusPagesResponse(BaseModel):
    data: List[V4StatusPagesStatusPage]

    meta: V4StatusPagesListStatusPagesResponseMeta



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_snoozenotifications_reassignto import (
    V3IncidentsSnoozeNotificationsReassignTo,
    V3IncidentsSnoozeNotificationsReassignToTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequestTypedDict(TypedDict):
    reassign_to: V3IncidentsSnoozeNotificationsReassignToTypedDict


class V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequest(BaseModel):
    reassign_to: V3IncidentsSnoozeNotificationsReassignTo



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_overlay_customcontentoverlayresponse import (
    V3ServicesOverlayCustomContentOverlayResponse,
    V3ServicesOverlayCustomContentOverlayResponseTypedDict,
)
from .v3_services_overlay_updatecustomcontenttemplateoverlayrequest import (
    V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest,
    V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverlayCreateOrUpdateNotificationTemplateOverlayRequestTypedDict(TypedDict):
    service_id: str
    alert_source: str
    v3_services_overlay_update_custom_content_template_overlay_request: (
        V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict
    )


class OverlayCreateOrUpdateNotificationTemplateOverlayRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    alert_source: Annotated[
        str,
        pydantic.Field(alias="alertSource"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_overlay_update_custom_content_template_overlay_request: Annotated[
        V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverlayCreateOrUpdateNotificationTemplateOverlayResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ServicesOverlayCustomContentOverlayResponseTypedDict


class OverlayCreateOrUpdateNotificationTemplateOverlayResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ServicesOverlayCustomContentOverlayResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_auditlogsexporthistoryresponse import (
    V3AuditLogsAuditLogsExportHistoryResponse,
    V3AuditLogsAuditLogsExportHistoryResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict(TypedDict):
    total_count: int


class V3AuditLogsListAuditLogsExportHistoryResponseMetadata(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]


class V3AuditLogsListAuditLogsExportHistoryResponseTypedDict(TypedDict):
    r"""Response model for listing audit logs export history"""

    data: List[V3AuditLogsAuditLogsExportHistoryResponseTypedDict]
    metadata: V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict


class V3AuditLogsListAuditLogsExportHistoryResponse(BaseModel):
    r"""Response model for listing audit logs export history"""

    data: List[V3AuditLogsAuditLogsExportHistoryResponse]

    metadata: V3AuditLogsListAuditLogsExportHistoryResponseMetadata



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4ICalLinkResponseTypedDict(TypedDict):
    i_cal_link: NotRequired[str]
    i_cal_link_for_my_on_calls: NotRequired[str]


class V4ICalLinkResponse(BaseModel):
    i_cal_link: Annotated[Optional[str], pydantic.Field(alias="iCalLink")] = None

    i_cal_link_for_my_on_calls: Annotated[
        Optional[str], pydantic.Field(alias="iCalLinkForMyOnCalls")
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_orderingresponse import (
    V3GlobalEventRulesOrderingResponse,
    V3GlobalEventRulesOrderingResponseTypedDict,
)
from .v3_globaleventrules_reorderrulerequest import (
    V3GlobalEventRulesReorderRuleRequest,
    V3GlobalEventRulesReorderRuleRequestTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class GlobalEventRulesReorderRulesetByIndexRequestTypedDict(TypedDict):
    ger_id: int
    alert_source_version: str
    alert_source_shortname: str
    rule_id: str
    v3_global_event_rules_reorder_rule_request: (
        V3GlobalEventRulesReorderRuleRequestTypedDict
    )


class GlobalEventRulesReorderRulesetByIndexRequest(BaseModel):
    ger_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_version: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_shortname: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    rule_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    v3_global_event_rules_reorder_rule_request: Annotated[
        V3GlobalEventRulesReorderRuleRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class GlobalEventRulesReorderRulesetByIndexResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesOrderingResponseTypedDict


class GlobalEventRulesReorderRulesetByIndexResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesOrderingResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_serviceresponse import (
    V3ServicesServiceResponse,
    V3ServicesServiceResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ServicesGetServiceByIDRequestTypedDict(TypedDict):
    service_id: str


class ServicesGetServiceByIDRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class ServicesGetServiceByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ServicesServiceResponseTypedDict


class ServicesGetServiceByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ServicesServiceResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_getissuebyidresponse import (
    V4StatusPagesIssuesGetIssueByIDResponse,
    V4StatusPagesIssuesGetIssueByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class IssuesGetIssueByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    issue_id: str


class IssuesGetIssueByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    issue_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class IssuesGetIssueByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesGetIssueByIDResponseTypedDict


class IssuesGetIssueByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesGetIssueByIDResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from jsonpath import JSONPath
from squadcast_sdk import errors, models, utils
from squadcast_sdk._hooks import HookContext
from squadcast_sdk.types import OptionalNullable, UNSET
from squadcast_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Dict, List, Mapping, Optional, Union


class WebformsSDK(BaseSDK):
    def list(
        self,
        *,
        owner_id: str,
        page_number: Optional[int] = None,
        page_size: Optional[int] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.WebformsGetAllWebformsResponse]:
        r"""Get All Webforms

        Returns all webforms of the given `owner_id` (teamId) in the request param.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param owner_id:
        :param page_number:
        :param page_size:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsGetAllWebformsRequest(
            owner_id=owner_id,
            page_number=page_number,
            page_size=page_size,
        )

        req = self._build_request(
            method="GET",
            path="/v3/webform",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_getAllWebforms",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        def next_func() -> Optional[models.WebformsGetAllWebformsResponse]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])
            page = request.page_number if not request.page_number is None else 1
            next_page = page + 1

            if not http_res.text:
                return None
            results = JSONPath("$.data").parse(body)
            if len(results) == 0 or len(results[0]) == 0:
                return None
            limit = request.page_size if not request.page_size is None else 0
            if len(results[0]) < limit:
                return None

            return self.list(
                owner_id=owner_id,
                page_number=next_page,
                page_size=page_size,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.WebformsGetAllWebformsResponse(
                result=unmarshal_json_response(
                    models.WebformsGetAllWebformsResponseBody, http_res
                ),
                next=next_func,
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        owner_id: str,
        page_number: Optional[int] = None,
        page_size: Optional[int] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.WebformsGetAllWebformsResponse]:
        r"""Get All Webforms

        Returns all webforms of the given `owner_id` (teamId) in the request param.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param owner_id:
        :param page_number:
        :param page_size:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsGetAllWebformsRequest(
            owner_id=owner_id,
            page_number=page_number,
            page_size=page_size,
        )

        req = self._build_request_async(
            method="GET",
            path="/v3/webform",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_getAllWebforms",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        def next_func() -> Optional[models.WebformsGetAllWebformsResponse]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])
            page = request.page_number if not request.page_number is None else 1
            next_page = page + 1

            if not http_res.text:
                return None
            results = JSONPath("$.data").parse(body)
            if len(results) == 0 or len(results[0]) == 0:
                return None
            limit = request.page_size if not request.page_size is None else 0
            if len(results[0]) < limit:
                return None

            return self.list(
                owner_id=owner_id,
                page_number=next_page,
                page_size=page_size,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.WebformsGetAllWebformsResponse(
                result=unmarshal_json_response(
                    models.WebformsGetAllWebformsResponseBody, http_res
                ),
                next=next_func,
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def create(
        self,
        *,
        owner_id: str,
        name: str,
        is_cname: bool,
        is_captcha_enabled: bool,
        captcha_secret: Union[
            models.V3WebformsRecaptchaSecrets,
            models.V3WebformsRecaptchaSecretsTypedDict,
        ],
        form_owner_type: str,
        form_owner_id: str,
        services: Union[
            List[models.V3WebformsWFService], List[models.V3WebformsWFServiceTypedDict]
        ],
        header: str,
        title: str,
        footer_text: str,
        footer_link: str,
        host_name: Optional[str] = None,
        tags: Optional[
            Union[
                models.V3WebformsCreateOrUpdateWebformRequestTags,
                models.V3WebformsCreateOrUpdateWebformRequestTagsTypedDict,
            ]
        ] = None,
        input_field: Optional[
            Union[
                List[models.V3WebformsWFInputField],
                List[models.V3WebformsWFInputFieldTypedDict],
            ]
        ] = None,
        logo_url: Optional[str] = None,
        email_on: Optional[List[str]] = None,
        description: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WebformsCreateWebformData:
        r"""Create Webform

        Add a webform to the organization. Returns the webform object in response.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param owner_id: Unique identifier of the owner (string or UUID)
        :param name: Name of the webform
        :param is_cname: Indicates if a custom domain (CNAME) is used
        :param is_captcha_enabled: Whether CAPTCHA is enabled on the form
        :param captcha_secret: CAPTCHA credentials to be validated
        :param form_owner_type: Entity type that owns the form (e.g., team, user)
        :param form_owner_id: Identifier for the owner entity
        :param services: List of services tied to this webform
        :param header: Header text shown on the form
        :param title: Title of the webform
        :param footer_text: Text displayed in the footer
        :param footer_link: Hyperlink in the footer (mailto or https)
        :param host_name: Custom hostname if CNAME is enabled
        :param tags: Key-value tags for the webform
        :param input_field: Input fields to be rendered on the form
        :param logo_url: URL to the organization's logo
        :param email_on: Emails to notify on submission
        :param description: Optional description for the webform
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.V3WebformsCreateOrUpdateWebformRequest(
            owner_id=owner_id,
            name=name,
            is_cname=is_cname,
            host_name=host_name,
            tags=utils.get_pydantic_model(
                tags, Optional[models.V3WebformsCreateOrUpdateWebformRequestTags]
            ),
            is_captcha_enabled=is_captcha_enabled,
            captcha_secret=utils.get_pydantic_model(
                captcha_secret, models.V3WebformsRecaptchaSecrets
            ),
            form_owner_type=form_owner_type,
            form_owner_id=form_owner_id,
            services=utils.get_pydantic_model(
                services, List[models.V3WebformsWFService]
            ),
            input_field=utils.get_pydantic_model(
                input_field, Optional[List[models.V3WebformsWFInputField]]
            ),
            header=header,
            title=title,
            logo_url=logo_url,
            footer_text=footer_text,
            footer_link=footer_link,
            email_on=email_on,
            description=description,
        )

        req = self._build_request(
            method="POST",
            path="/v3/webform",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "json",
                models.V3WebformsCreateOrUpdateWebformRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_createWebform",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(
                models.WebformsCreateWebformResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        owner_id: str,
        name: str,
        is_cname: bool,
        is_captcha_enabled: bool,
        captcha_secret: Union[
            models.V3WebformsRecaptchaSecrets,
            models.V3WebformsRecaptchaSecretsTypedDict,
        ],
        form_owner_type: str,
        form_owner_id: str,
        services: Union[
            List[models.V3WebformsWFService], List[models.V3WebformsWFServiceTypedDict]
        ],
        header: str,
        title: str,
        footer_text: str,
        footer_link: str,
        host_name: Optional[str] = None,
        tags: Optional[
            Union[
                models.V3WebformsCreateOrUpdateWebformRequestTags,
                models.V3WebformsCreateOrUpdateWebformRequestTagsTypedDict,
            ]
        ] = None,
        input_field: Optional[
            Union[
                List[models.V3WebformsWFInputField],
                List[models.V3WebformsWFInputFieldTypedDict],
            ]
        ] = None,
        logo_url: Optional[str] = None,
        email_on: Optional[List[str]] = None,
        description: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.WebformsCreateWebformData:
        r"""Create Webform

        Add a webform to the organization. Returns the webform object in response.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param owner_id: Unique identifier of the owner (string or UUID)
        :param name: Name of the webform
        :param is_cname: Indicates if a custom domain (CNAME) is used
        :param is_captcha_enabled: Whether CAPTCHA is enabled on the form
        :param captcha_secret: CAPTCHA credentials to be validated
        :param form_owner_type: Entity type that owns the form (e.g., team, user)
        :param form_owner_id: Identifier for the owner entity
        :param services: List of services tied to this webform
        :param header: Header text shown on the form
        :param title: Title of the webform
        :param footer_text: Text displayed in the footer
        :param footer_link: Hyperlink in the footer (mailto or https)
        :param host_name: Custom hostname if CNAME is enabled
        :param tags: Key-value tags for the webform
        :param input_field: Input fields to be rendered on the form
        :param logo_url: URL to the organization's logo
        :param email_on: Emails to notify on submission
        :param description: Optional description for the webform
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.V3WebformsCreateOrUpdateWebformRequest(
            owner_id=owner_id,
            name=name,
            is_cname=is_cname,
            host_name=host_name,
            tags=utils.get_pydantic_model(
                tags, Optional[models.V3WebformsCreateOrUpdateWebformRequestTags]
            ),
            is_captcha_enabled=is_captcha_enabled,
            captcha_secret=utils.get_pydantic_model(
                captcha_secret, models.V3WebformsRecaptchaSecrets
            ),
            form_owner_type=form_owner_type,
            form_owner_id=form_owner_id,
            services=utils.get_pydantic_model(
                services, List[models.V3WebformsWFService]
            ),
            input_field=utils.get_pydantic_model(
                input_field, Optional[List[models.V3WebformsWFInputField]]
            ),
            header=header,
            title=title,
            logo_url=logo_url,
            footer_text=footer_text,
            footer_link=footer_link,
            email_on=email_on,
            description=description,
        )

        req = self._build_request_async(
            method="POST",
            path="/v3/webform",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "json",
                models.V3WebformsCreateOrUpdateWebformRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_createWebform",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(
                models.WebformsCreateWebformResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def update(
        self,
        *,
        webform_id: int,
        owner_id: str,
        name: str,
        is_cname: bool,
        is_captcha_enabled: bool,
        captcha_secret: Union[
            models.V3WebformsRecaptchaSecrets,
            models.V3WebformsRecaptchaSecretsTypedDict,
        ],
        form_owner_type: str,
        form_owner_id: str,
        services: Union[
            List[models.V3WebformsWFService], List[models.V3WebformsWFServiceTypedDict]
        ],
        header: str,
        title: str,
        footer_text: str,
        footer_link: str,
        host_name: Optional[str] = None,
        tags: Optional[
            Union[
                models.V3WebformsCreateOrUpdateWebformRequestTags,
                models.V3WebformsCreateOrUpdateWebformRequestTagsTypedDict,
            ]
        ] = None,
        input_field: Optional[
            Union[
                List[models.V3WebformsWFInputField],
                List[models.V3WebformsWFInputFieldTypedDict],
            ]
        ] = None,
        logo_url: Optional[str] = None,
        email_on: Optional[List[str]] = None,
        description: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3WebformsWebformResponse:
        r"""Update Webform

        Update a webform to the organization. Returns the webform object in response.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param webform_id:
        :param owner_id: Unique identifier of the owner (string or UUID)
        :param name: Name of the webform
        :param is_cname: Indicates if a custom domain (CNAME) is used
        :param is_captcha_enabled: Whether CAPTCHA is enabled on the form
        :param captcha_secret: CAPTCHA credentials to be validated
        :param form_owner_type: Entity type that owns the form (e.g., team, user)
        :param form_owner_id: Identifier for the owner entity
        :param services: List of services tied to this webform
        :param header: Header text shown on the form
        :param title: Title of the webform
        :param footer_text: Text displayed in the footer
        :param footer_link: Hyperlink in the footer (mailto or https)
        :param host_name: Custom hostname if CNAME is enabled
        :param tags: Key-value tags for the webform
        :param input_field: Input fields to be rendered on the form
        :param logo_url: URL to the organization's logo
        :param email_on: Emails to notify on submission
        :param description: Optional description for the webform
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsUpdateWebformRequest(
            webform_id=webform_id,
            v3_webforms_create_or_update_webform_request=models.V3WebformsCreateOrUpdateWebformRequest(
                owner_id=owner_id,
                name=name,
                is_cname=is_cname,
                host_name=host_name,
                tags=utils.get_pydantic_model(
                    tags, Optional[models.V3WebformsCreateOrUpdateWebformRequestTags]
                ),
                is_captcha_enabled=is_captcha_enabled,
                captcha_secret=utils.get_pydantic_model(
                    captcha_secret, models.V3WebformsRecaptchaSecrets
                ),
                form_owner_type=form_owner_type,
                form_owner_id=form_owner_id,
                services=utils.get_pydantic_model(
                    services, List[models.V3WebformsWFService]
                ),
                input_field=utils.get_pydantic_model(
                    input_field, Optional[List[models.V3WebformsWFInputField]]
                ),
                header=header,
                title=title,
                logo_url=logo_url,
                footer_text=footer_text,
                footer_link=footer_link,
                email_on=email_on,
                description=description,
            ),
        )

        req = self._build_request(
            method="PUT",
            path="/v3/webform/{webformId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.v3_webforms_create_or_update_webform_request,
                False,
                False,
                "json",
                models.V3WebformsCreateOrUpdateWebformRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_updateWebform",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebformsUpdateWebformResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        webform_id: int,
        owner_id: str,
        name: str,
        is_cname: bool,
        is_captcha_enabled: bool,
        captcha_secret: Union[
            models.V3WebformsRecaptchaSecrets,
            models.V3WebformsRecaptchaSecretsTypedDict,
        ],
        form_owner_type: str,
        form_owner_id: str,
        services: Union[
            List[models.V3WebformsWFService], List[models.V3WebformsWFServiceTypedDict]
        ],
        header: str,
        title: str,
        footer_text: str,
        footer_link: str,
        host_name: Optional[str] = None,
        tags: Optional[
            Union[
                models.V3WebformsCreateOrUpdateWebformRequestTags,
                models.V3WebformsCreateOrUpdateWebformRequestTagsTypedDict,
            ]
        ] = None,
        input_field: Optional[
            Union[
                List[models.V3WebformsWFInputField],
                List[models.V3WebformsWFInputFieldTypedDict],
            ]
        ] = None,
        logo_url: Optional[str] = None,
        email_on: Optional[List[str]] = None,
        description: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3WebformsWebformResponse:
        r"""Update Webform

        Update a webform to the organization. Returns the webform object in response.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param webform_id:
        :param owner_id: Unique identifier of the owner (string or UUID)
        :param name: Name of the webform
        :param is_cname: Indicates if a custom domain (CNAME) is used
        :param is_captcha_enabled: Whether CAPTCHA is enabled on the form
        :param captcha_secret: CAPTCHA credentials to be validated
        :param form_owner_type: Entity type that owns the form (e.g., team, user)
        :param form_owner_id: Identifier for the owner entity
        :param services: List of services tied to this webform
        :param header: Header text shown on the form
        :param title: Title of the webform
        :param footer_text: Text displayed in the footer
        :param footer_link: Hyperlink in the footer (mailto or https)
        :param host_name: Custom hostname if CNAME is enabled
        :param tags: Key-value tags for the webform
        :param input_field: Input fields to be rendered on the form
        :param logo_url: URL to the organization's logo
        :param email_on: Emails to notify on submission
        :param description: Optional description for the webform
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsUpdateWebformRequest(
            webform_id=webform_id,
            v3_webforms_create_or_update_webform_request=models.V3WebformsCreateOrUpdateWebformRequest(
                owner_id=owner_id,
                name=name,
                is_cname=is_cname,
                host_name=host_name,
                tags=utils.get_pydantic_model(
                    tags, Optional[models.V3WebformsCreateOrUpdateWebformRequestTags]
                ),
                is_captcha_enabled=is_captcha_enabled,
                captcha_secret=utils.get_pydantic_model(
                    captcha_secret, models.V3WebformsRecaptchaSecrets
                ),
                form_owner_type=form_owner_type,
                form_owner_id=form_owner_id,
                services=utils.get_pydantic_model(
                    services, List[models.V3WebformsWFService]
                ),
                input_field=utils.get_pydantic_model(
                    input_field, Optional[List[models.V3WebformsWFInputField]]
                ),
                header=header,
                title=title,
                logo_url=logo_url,
                footer_text=footer_text,
                footer_link=footer_link,
                email_on=email_on,
                description=description,
            ),
        )

        req = self._build_request_async(
            method="PUT",
            path="/v3/webform/{webformId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.v3_webforms_create_or_update_webform_request,
                False,
                False,
                "json",
                models.V3WebformsCreateOrUpdateWebformRequest,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_updateWebform",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebformsUpdateWebformResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def remove(
        self,
        *,
        webform_id: int,
        owner_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> str:
        r"""Remove Webform

        Remove a webform from the organization.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param webform_id:
        :param owner_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsRemoveWebformRequest(
            webform_id=webform_id,
            owner_id=owner_id,
        )

        req = self._build_request(
            method="DELETE",
            path="/v3/webform/{webformId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_removeWebform",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebformsRemoveWebformResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def remove_async(
        self,
        *,
        webform_id: int,
        owner_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> str:
        r"""Remove Webform

        Remove a webform from the organization.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `user-write` scope.

        :param webform_id:
        :param owner_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsRemoveWebformRequest(
            webform_id=webform_id,
            owner_id=owner_id,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v3/webform/{webformId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_removeWebform",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebformsRemoveWebformResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    def get_by_id(
        self,
        *,
        webform_id: int,
        owner_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3WebformsWebformResponse:
        r"""Get Webform By ID

        Returns a webform details of the given `webformId` in the request param.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param webform_id:
        :param owner_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsGetWebformByIDRequest(
            webform_id=webform_id,
            owner_id=owner_id,
        )

        req = self._build_request(
            method="GET",
            path="/v3/webform/{webformId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_getWebformById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebformsGetWebformByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)

    async def get_by_id_async(
        self,
        *,
        webform_id: int,
        owner_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.V3WebformsWebformResponse:
        r"""Get Webform By ID

        Returns a webform details of the given `webformId` in the request param.
        Requires `access_token` as a `Bearer {{token}}` in the `Authorization` header with `read` scope.

        :param webform_id:
        :param owner_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.WebformsGetWebformByIDRequest(
            webform_id=webform_id,
            owner_id=owner_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/v3/webform/{webformId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="Webforms_getWebformById",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "402",
                "403",
                "404",
                "409",
                "422",
                "4XX",
                "500",
                "502",
                "503",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.WebformsGetWebformByIDResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnauthorizedErrorData, http_res
            )
            raise errors.UnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "402", "application/json"):
            response_data = unmarshal_json_response(
                errors.PaymentRequiredErrorData, http_res
            )
            raise errors.PaymentRequiredError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(errors.ForbiddenErrorData, http_res)
            raise errors.ForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(errors.NotFoundErrorData, http_res)
            raise errors.NotFoundError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(errors.ConflictErrorData, http_res)
            raise errors.ConflictError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.UnprocessableEntityErrorData, http_res
            )
            raise errors.UnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "502", "application/json"):
            response_data = unmarshal_json_response(
                errors.BadGatewayErrorData, http_res
            )
            raise errors.BadGatewayError(response_data, http_res)
        if utils.match_response(http_res, "503", "application/json"):
            response_data = unmarshal_json_response(
                errors.ServiceUnavailableErrorData, http_res
            )
            raise errors.ServiceUnavailableError(response_data, http_res)
        if utils.match_response(http_res, "504", "application/json"):
            response_data = unmarshal_json_response(
                errors.GatewayTimeoutErrorData, http_res
            )
            raise errors.GatewayTimeoutError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.SDKDefaultError("API error occurred", http_res, http_res_text)

        raise errors.SDKDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_postmortems_createpostmortemrequest import (
    V3IncidentsPostmortemsCreatePostmortemRequest,
    V3IncidentsPostmortemsCreatePostmortemRequestTypedDict,
)
from .v3_incidents_postmortems_postmortemresponse import (
    V3IncidentsPostmortemsPostmortemResponse,
    V3IncidentsPostmortemsPostmortemResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostmortemsCreatePostmortemRequestTypedDict(TypedDict):
    incident_id: str
    v3_incidents_postmortems_create_postmortem_request: (
        V3IncidentsPostmortemsCreatePostmortemRequestTypedDict
    )


class PostmortemsCreatePostmortemRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_postmortems_create_postmortem_request: Annotated[
        V3IncidentsPostmortemsCreatePostmortemRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class PostmortemsCreatePostmortemBodyTypedDict(TypedDict):
    r"""The body type of the operation request or response."""

    data: V3IncidentsPostmortemsPostmortemResponseTypedDict


class PostmortemsCreatePostmortemBody(BaseModel):
    r"""The body type of the operation request or response."""

    data: V3IncidentsPostmortemsPostmortemResponse


class PostmortemsCreatePostmortemResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    body: PostmortemsCreatePostmortemBodyTypedDict
    r"""The body type of the operation request or response."""


class PostmortemsCreatePostmortemResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    body: PostmortemsCreatePostmortemBody
    r"""The body type of the operation request or response."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_extensions_webhooks_webhooklistitem import (
    V3ExtensionsWebhooksWebhookListItem,
    V3ExtensionsWebhooksWebhookListItemTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict(TypedDict):
    total_count: int


class V3ExtensionsWebhooksGetAllWebhooksResponseMeta(BaseModel):
    total_count: int


class V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict(TypedDict):
    result: List[V3ExtensionsWebhooksWebhookListItemTypedDict]
    meta: V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict


class V3ExtensionsWebhooksGetAllWebhooksResponseData(BaseModel):
    result: List[V3ExtensionsWebhooksWebhookListItem]

    meta: V3ExtensionsWebhooksGetAllWebhooksResponseMeta


class V3ExtensionsWebhooksGetAllWebhooksResponseTypedDict(TypedDict):
    data: V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict


class V3ExtensionsWebhooksGetAllWebhooksResponse(BaseModel):
    data: V3ExtensionsWebhooksGetAllWebhooksResponseData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamresponse import V3TeamsTeamResponse, V3TeamsTeamResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class TeamsGetTeamByIDRequestTypedDict(TypedDict):
    team_id: str


class TeamsGetTeamByIDRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class TeamsGetTeamByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3TeamsTeamResponseTypedDict


class TeamsGetTeamByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3TeamsTeamResponse
